.. _spkg:

Packages and Features
=====================

Standard Packages
-----------------

The Sage distribution includes most programs and libraries on which
Sage depends.  It installs them automatically if it does not find
equivalent system packages.

.. include:: index_standard.rst


Optional Packages
-----------------

For additional functionality, you can install some of the following
optional packages.

.. include:: index_optional.rst


Features
--------

.. toctree::
   :maxdepth: 1

   sage/features
   sage/features/join_feature
   sage/features/all
   sage/features/sagemath
   sage/features/pkg_systems
   sage/features/standard
   sage/features/bliss
   sage/features/cddlib
   sage/features/coxeter3
   sage/features/csdp
   sage/features/cython
   sage/features/databases
   sage/features/dot2tex
   sage/features/dvipng
   sage/features/eclib
   sage/features/ecm
   sage/features/ffmpeg
   sage/features/four_ti_2
   sage/features/fricas
   sage/features/frobby
   sage/features/gap
   sage/features/gfan
   sage/features/giac
   sage/features/graph_generators
   sage/features/graphviz
   sage/features/igraph
   sage/features/imagemagick
   sage/features/info
   sage/features/interfaces
   sage/features/internet
   sage/features/jmol
   sage/features/kenzo
   sage/features/latex
   sage/features/latte
   sage/features/lrs
   sage/features/macaulay2
   sage/features/mcqd
   sage/features/meataxe
   sage/features/mip_backends
   sage/features/msolve
   sage/features/nauty
   sage/features/normaliz
   sage/features/palp
   sage/features/pandoc
   sage/features/pari
   sage/features/pdf2svg
   sage/features/phitigra
   sage/features/polymake
   sage/features/poppler
   sage/features/qepcad
   sage/features/rubiks
   sage/features/sat
   sage/features/singular
   sage/features/sirocco
   sage/features/sloane_database
   sage/features/sphinx
   sage/features/symengine_py
   sage/features/sympow
   sage/features/tachyon
   sage/features/tdlib
   sage/features/threejs
   sage/features/topcom


pip-installable passagemath Packages
------------------------------------

The passagemath project publishes the Sage library in modularized
form as pip-installable source and binary wheel packages. They
can be built, installed, and tested separately.

.. include:: index_sagemath.rst


Experimental Packages
---------------------

Some packages that provide additional functionality are marked as
"experimental".  Developers are needed in order to improve the
integration of these packages into the Sage distribution.

.. include:: index_experimental.rst


All External Packages
---------------------

.. toctree::
   :maxdepth: 1

   index_alph

